summaryrefslogtreecommitdiff
path: root/src/cmd/vendor/golang.org/x/sys
diff options
context:
space:
mode:
authorJoshua M. Clulow <josh.clulow@joyent.com>2019-04-29 13:50:49 +0000
committerBrad Fitzpatrick <bradfitz@golang.org>2019-04-30 16:59:13 +0000
commitf686a2890b34996455c7d7aba9a0efba74b613f5 (patch)
treed2f0348349a47f4697fb4dacdf687455cec4546a /src/cmd/vendor/golang.org/x/sys
parent0c9e0c257b121acae72b9419be64ce45196ef825 (diff)
downloadgo-git-f686a2890b34996455c7d7aba9a0efba74b613f5.tar.gz
all: add new GOOS=illumos, split out of GOOS=solaris
Like GOOS=android which implies the "linux" build tag, GOOS=illumos implies the "solaris" build tag. This lets the existing ecosystem of packages still work on illumos, but still permits packages to start differentiating between solaris and illumos. Fixes #20603 Change-Id: I8f4eabf1a66060538dca15d7658c1fbc6c826622 Reviewed-on: https://go-review.googlesource.com/c/go/+/174457 Run-TryBot: Benny Siegert <bsiegert@gmail.com> Reviewed-by: Benny Siegert <bsiegert@gmail.com> Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org> TryBot-Result: Gobot Gobot <gobot@golang.org>
Diffstat (limited to 'src/cmd/vendor/golang.org/x/sys')
-rw-r--r--src/cmd/vendor/golang.org/x/sys/unix/sockcmsg_unix.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/cmd/vendor/golang.org/x/sys/unix/sockcmsg_unix.go b/src/cmd/vendor/golang.org/x/sys/unix/sockcmsg_unix.go
index 723b7f1012..a79565a7ff 100644
--- a/src/cmd/vendor/golang.org/x/sys/unix/sockcmsg_unix.go
+++ b/src/cmd/vendor/golang.org/x/sys/unix/sockcmsg_unix.go
@@ -21,9 +21,9 @@ func cmsgAlignOf(salen int) int {
case "aix":
// There is no alignment on AIX.
salign = 1
- case "darwin", "dragonfly", "solaris":
- // NOTE: It seems like 64-bit Darwin, DragonFly BSD and
- // Solaris kernels still require 32-bit aligned access to
+ case "darwin", "dragonfly", "solaris", "illumos":
+ // NOTE: It seems like 64-bit Darwin, DragonFly BSD, illumos,
+ // and Solaris kernels still require 32-bit aligned access to
// network subsystem.
if SizeofPtr == 8 {
salign = 4